@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -96,8 +96,9 @@ public class ConfigurationRESTService {
 
         ComposedConfigProperty<String> p = view.property(property, String.class);
         try {
-            if (p.isDefined()) {
-                return new JSONObject().put(property, p.get());
+            String value = p.get();
+            if (value != null) {
+                return new JSONObject(2).put(property, value);
             }
             throw new NotFoundException();
         } catch (JSONException e) {
